<?
	/****************************************************************************
	* Software distributed under the License is distributed on an "AS IS" 		*
	* basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the 	*
	* License for a specific language governing rights and limitations under	*
	* the License. 																*
	* 																			*
	*	The Original Code is - InTerra Blog Machine   				            *
	* 																			*
	*	The Initial Developer of the Original Code is 							*
	* 																			*
	* 			Kulikov Alexey <alex [at] essentialmind [dot] com>	 			*
	* 																			*
	* 							All Rights Reserved. 							*
	* 																			*
	*****************************************************************************/
	
	class lj{
		var $user;	//@private
		var $pass;	//@private
		var $lj;	//@private
		
		/***
		 Concstructor
		 
		 @param user	-	user name
		 @param pass	-	password
		***/
		function lj($user,$pass){
			$this->createClient();
			$this->setUser($user);
			$this->setPass($pass);
		}
		
		/***
		 function lj::addPost
		 
		 purpose	add a new entry to the specified livejournal
		 
		 @param subject (string)
		 @param content (string)
		 @param date	(int -- unixtimestamp)
		 
		 @return array(itemid, anum), in order to calculate the itemid URL
		 you have to use the following formula: itemid*256 + anum
		***/
		function addPost($subject, $content, $date){
			//set message handler
			$message = new xmlrpcmsg('LJ.XMLRPC.postevent');
			
			//prepate message
			$message->addParam(xmlrpc_encode(array(
													"username"			=>	$this->getUser(),
													"hpassword"			=>	md5($this->getPass()),
													"clientversion"		=>	"InTerra Blog Machine",
													"event"				=>	$this->utf_encode("<lj-raw>".stripslashes($content)."</lj-raw>"),
													"subject"			=>	$this->utf_encode(stripslashes($subject)),
													"lineendings"		=>	"0x0A",
													"year"				=>	date("Y",$date),
													"mon"				=>	date("m",$date),
													"day"				=>	date("d",$date),
													"hour"				=>	date("H",$date),
													"min"				=>	date("i",$date),
													"ver"				=>	1
													)));
			
			//send the message to the server
			$response = $this->lj->send($message);
			
			//check what the reply is
			if($response->value()){	# all cool
				$response = xmlrpc_decode($response->value());
				return $response;
			}
			return false;
		}
		
		
		/***
		 function lj::updatePost
		 
		 purpose	updates an entry in the specified livejournal
		 
		 @param	entryid	(int)
		 @param subject (string)
		 @param content (string)
		 @param date	(int -- unixtimestamp)
		 @return bool
		***/
		function updatePost($entryid,$subject,$content,$date){
			//set message handler
			$message = new xmlrpcmsg('LJ.XMLRPC.editevent');
			
			//prepare content such that deletion works =)
			if($content){
				$content = "<lj-raw>".stripslashes($content)."</lj-raw>";	
			}
			
			//prepate message
			$message->addParam(xmlrpc_encode(array(
													"username"			=>	$this->getUser(),
													"hpassword"			=>	md5($this->getPass()),
													"clientversion"		=>	"InTerra Blog Machine",
													"event"				=>	$this->utf_encode($content),
													"subject"			=>	$this->utf_encode(stripslashes($subject)),
													"lineendings"		=>	"0x0A",
													"year"				=>	date("Y",$date),
													"mon"				=>	date("m",$date),
													"day"				=>	date("d",$date),
													"hour"				=>	date("H",$date),
													"min"				=>	date("i",$date),
													"itemid"			=>	$entryid,
													"ver"				=>	1
													)));
			
			//send the message to the server
			$response = $this->lj->send($message);
			
			//check what the reply is
			if($response->value()){	# all cool
				return true;
			}
			return false;
		}
		
		
		/***
		 function lj::dropPost()
		 
		 purpose	deletes an entry in the specified livejournal
		 
		 @param	entryid	(int)
		***/
		function dropPost($entryid){
			return $this->updatePost($entryid,null,null,time());
		}
		
		
		/***
		 lj::setUser()
		 
		 sets the current LJ user
		 
		 @param user (string)
		***/
		function setUser($user){
			$this->user = $user;
		}
		
		
		/***
		 lj::setPass()
		 
		 sets the current LJ password
		 
		 @param pass (string)
		***/
		function setPass($pass){
			$this->pass = $pass;	
		}
		
		
		/***
		 lj::createClient()
		 
		 initializes a livejournal RPC client
		 
		 @param server (string)
		 @param interface (string)
		 @param port (int)
		 @access private
		***/
		function createClient($server='www.livejournal.com', $interface='/interface/xmlrpc', $port=80){
			$this->lj = new xmlrpc_client($interface, $server, $port);
		}
		
		
		/***
		 lj::getUser()
		 
		 returns the current LJ user
		***/
		function getUser(){
			return $this->user;	
		}
		
		
		/***
		 lj::getPass()
		 
		 returns the current lj pass
		***/
		function getPass(){
			return $this->pass;
		}

		
		/***
		 lj:utf_encode()
		 
		 to encode win1251 data into pure utf-8 without the use of iconv()
		 
		 @param s (string)
		 @access private
		***/
		function utf_encode($s){
			return iconv("CP1251","UTF-8",$s);
		}
	}
?>